==> cscec5bhn-wzxt-api-3.0.1-20221025.120103-102-sources.jar: com/ejianc/business/wzxt/vo/CheckAllotVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 验收调拨表
 *
 * @author generator
 *
 */
public class CheckAllotVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long checkId; // 验收主键ID
    private Long checkDetailId; // 验收明细主键ID
    private Long supplierId; // 供应商主键ID
    private String ncSupplierId; // NC供应商主键
    private String contractId; // NC合同主键
    private String memo; // 备注
    private String def1; // 自定义字段1
    private String def2; // 自定义字段2
    private String def3; // 自定义字段3
    private String def4; // 自定义字段4
    private String def5; // 自定义字段5
    private String unitId; // 档案单位主键
    private String unitName; // 档案单位名称
    private BigDecimal num; // 数量
    private String realUnitId; // 实物单位主键
    private String realUnitName; // 实物单位名称
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal realNum; // 实物数量
    private String rentUnitId; // 计租单位主键
    private String rentUnitName; // 计租单位名称
    private BigDecimal rentTransScale; // 计租转换系数
    private BigDecimal rentNum; // 计租数量


    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getCheckDetailId() {
        return checkDetailId;
    }

    public void setCheckDetailId(Long checkDetailId) {
        this.checkDetailId = checkDetailId;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getNcSupplierId() {
        return ncSupplierId;
    }

    public void setNcSupplierId(String ncSupplierId) {
        this.ncSupplierId = ncSupplierId;
    }
    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }
    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }
    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }
    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }
    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }

}

==> cscec5bhn-wzxt-api-3.0.1-20221028.073855-116-sources.jar: com/ejianc/business/wzxt/vo/CheckAllotVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 验收调拨表
 *
 * @author generator
 *
 */
public class CheckAllotVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long checkId; // 验收主键ID
    private Long checkDetailId; // 验收明细主键ID
    private Long supplierId; // 供应商主键ID   参照带出  id
    private String ncSupplierId; // NC供应商主键    参照带出  sourceId
    private String contractId; // NC合同主键  不用管
    private String memo; // 备注
    private String def1; // 自定义字段1
    private String def2; // 自定义字段2
    private String def3; // 自定义字段3
    private String def4; // 自定义字段4
    private String def5; // 自定义字段5
    private String unitId; // 档案单位主键   表体  unitId
    private String unitName; // 档案单位名称  表体  unit
    private BigDecimal num; // 数量  计算得来  规则同表体
    private String realUnitId; // 实物单位主键  表体  realUnitId
    private String realUnitName; // 实物单位名称  表体  realUnitName
    private BigDecimal realTransScale; // 实物转换系数   表体  realTransScale
    private BigDecimal realNum; // 实物数量   手动输入
    private String rentUnitId; // 计租单位主键  表体  rentUnitId
    private String rentUnitName; // 计租单位名称  表体  rentUnitName
    private BigDecimal rentTransScale; // 计租转换系数  表体  rentTransScale
    private BigDecimal rentNum; // 计租数量 计算得来  规则同表体


    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getCheckDetailId() {
        return checkDetailId;
    }

    public void setCheckDetailId(Long checkDetailId) {
        this.checkDetailId = checkDetailId;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getNcSupplierId() {
        return ncSupplierId;
    }

    public void setNcSupplierId(String ncSupplierId) {
        this.ncSupplierId = ncSupplierId;
    }
    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }
    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }
    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }
    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }
    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }

}
